<#import "traversal_utils.ftl" as utils>
<#compress>
<#-- Root entity -->
<#assign rootEntity = entity.root>
<#-- Define the main macro to be used to retrieve output by the traversal approach -->
<#assign mainMacroName = "printIfAttachmentElementNode"/>
<#assign mainMacroArgs = ['docElementNode', 'sectionNode', 'entityDocument', 'level']/>
<#-- Make global the macroCall as well as each macro used in it -->
<#global mainMacroCall="<@" + mainMacroName + " " + mainMacroArgs?join(" ") + "/>"/>
<#global printIfAttachmentElementNode = printIfAttachmentElementNode/>
<#global printAttachmentField = printAttachmentField/>
<#-- Print CSV header row -->
<@printCsvHeadersRow />
<#-- Traversal approach: prints one row per claim -->
<@utils.traversal rootEntity 8/>
</#compress>
<#---------------------------------------------->
<#-- Macro and function definitions start here -->
<#----------------------------------------------->
<#macro printIfAttachmentElementNode docElementNode sectionNode entityDocument level>

  <#-- traverse through the document's meta attachments -->
  <#if level==0>
      <#if docElementNode.attachments?has_content>
          <#assign docAttachments = docElementNode.attachments />
          <#list docAttachments as attachmentKey>
              <#if attachmentKey?has_content>
                <@printAttachmentField attachmentKey docElementNode sectionNode entityDocument/>
              </#if>
          </#list>
      </#if>
  </#if>

  <#if docElementNode?node_type == "attachment">
    <#-- the string represenetation of the element node represents the attachment key -->
    <#local attachmentKey = docElementNode>
    <@printAttachmentField attachmentKey docElementNode sectionNode entityDocument/>
  </#if>

  <#if docElementNode?node_type == "attachments">
     <#list docElementNode as item>
      <#-- the string represenetation of item represents the attachment key -->
      <#local attachmentKey = item>
      <@printAttachmentField attachmentKey docElementNode sectionNode entityDocument/>
     </#list>
  </#if>
</#macro>

<#macro printAttachmentField attachmentKey fieldNode sectionNode entityDocument>
    <#-- Attachment metadata -->
    <#local attachmentMetaData = iuclid.getMetadataForAttachment(attachmentKey)>
    <#local attachmentSize = "">
    <#if attachmentMetaData.size?has_content>
      <#local attachmentSize = attachmentMetaData.size?string["0.####"]>
    </#if>
    <#-- Section -->
    <#local sectionName = "">
    <#if sectionNode?has_content>
      <#if sectionNode.number?has_content>
        <#local sectionName = sectionNode.number + " ">
      </#if>
      <#local sectionName = sectionName + sectionNode.title>
    </#if>
    <#-- Section doc: the root of the fieldNode is the node that represents the Document to which the field belongs to -->
    <#assign sectionDoc = fieldNode?root>
    <#local sectionDocType = sectionDoc.documentType>
    <#local glp=getGLP(sectionDoc)/>
    <#local cfd=getCFD(sectionDoc)/>
    <#if !utils.isEntityDocument(sectionDoc)>
      <#local sectionDocType = sectionDocType + "." + sectionDoc.documentSubType>
    </#if>
    <#-- Path -->
    <#local fieldPath = fieldNode._path>
    <#-- The field label -->
    <@iuclid.label for=fieldNode var="fieldLabel"/>
    <#-- The web URL pointing to the document -->
    <#assign docUrl=utils.getDocumentUrl(sectionDoc) />
    <#-- If the attachment belongs to a LITERATURE, print some extra information -->
    <#local literatureAuthor = "">
    <#local literatureTitle = "">
    <#local literatureYear = "">
    <#local literatureReportNo = "">
    <#local literatureReportDate = "">
    <#local literatureSource = "">
    <#if entityDocument.documentType == "LITERATURE">
      <#if entityDocument.GeneralInfo.Author?has_content>
        <#local literatureAuthor = entityDocument.GeneralInfo.Author>
      </#if>
      <#if entityDocument.GeneralInfo.Name?has_content>
        <#local literatureTitle = entityDocument.GeneralInfo.Name>
      </#if>
      <#if entityDocument.GeneralInfo.ReferenceYear?has_content>
        <#local literatureYear = entityDocument.GeneralInfo.ReferenceYear>
      </#if>
      <#if entityDocument.GeneralInfo.ReportNo?has_content>
        <#local literatureReportNo = entityDocument.GeneralInfo.ReportNo>
      </#if>
      <#if entityDocument.GeneralInfo.ReportDate?has_content>
        <#local literatureReportDate = entityDocument.GeneralInfo.ReportDate>
      </#if>
      <#if entityDocument.GeneralInfo.Source?has_content>
        <#local literatureSource = entityDocument.GeneralInfo.Source>
      </#if>
    </#if>
    <@utils.csvValue attachmentMetaData.filename/>,${attachmentMetaData.md5},<@utils.csvValue attachmentMetaData.remarks/>,${attachmentMetaData.mediaType},${attachmentSize},<@utils.csvValue fieldLabel/>,${fieldPath},${sectionDocType},<@utils.csvValue sectionDoc.name/>,"=HYPERLINK(""${docUrl}"",""${sectionDoc.documentKey}"")",<@utils.csvValue cfd/>,<@utils.csvValue glp/>,<@utils.csvValue sectionName/>,${entityDocument.documentType},<@utils.csvValue entityDocument.name/>,${entityDocument.documentKey},${entityDocument.documentKey.snapshotUuid},<@utils.csvValue literatureAuthor/>,<@utils.csvValue literatureTitle/>,<@utils.csvValue literatureYear/>,<@utils.csvValue literatureReportNo/>,<@utils.csvValue literatureReportDate/>,<@utils.csvValue literatureSource/>,
</#macro>

<#macro printCsvHeadersRow>
"Attachment file name","MD5 checksum","Attachment remarks","Attachment media type","Attachment file size","Attachment field label","Attachment field path","Document type","Document name","Document UUID","Document confidentiality","GLP","Section","Entity type","Entity name","Entity UUID","Dossier UUID","Author","Title","Year","Report No.","Report date","Source",
</#macro>

<#--Function to extract Conf claim info from a document - usually ENDPOINT STUDY RECORD
    NOTE: in some special cases the path is different + it extracts the info from the document and not from parent of document
-->
<#function getCFD doc>
  <#local conf=""/>

  <#local flagPath=""/>
  <#if doc.hasElement("AdministrativeData.DataProtection")>
    <#--in ENDPOINT_STUDY_RECORD (at least)-->
    <#local flagPath="doc.AdministrativeData.DataProtection"/>
  <#elseif doc.hasElement("AdministrativeDataSummary.DataProtection")>
    <#--in SUMMARY_RECORD (at least)-->
    <#local flagPath="doc.AdministrativeDataSummary.DataProtection"/>>
  <#elseif doc.hasElement("DataProtection")>
      <#--in some FLEXIBLE RECORDS: Supplieres, Sites, GhS-->
      <#local flagPath="doc.DataProtection"/>
  </#if>

  <#if flagPath!="">
    <#local confPath=flagPath?eval />

    <#local confidentiality = utils.getPhraseCodeValue(confPath.confidentiality)>
     
    <#local conf><#if confidentiality?has_content>[${confidentiality}] </#if>${confPath.justification}</#local>
  </#if>

  <#return conf/>

</#function>

<#--Function to extract GLP info from a document - usually ENDPOINT STUDY RECORD
    NOTE: in some special cases the path is different
-->
<#function getGLP doc>
    <#local glp=""/>

    <#if doc.hasElement('MaterialsAndMethods.GLPComplianceStatement')>
      <#local glp>${utils.getPicklistFieldAsText(doc.MaterialsAndMethods.GLPComplianceStatement)}</#local>
    <#elseif doc.hasElement('MaterialsAndMethods.MethodUsed.GLPCompliance')><#--IntermediateEffects-->
      <#local glp>${utils.getPicklistFieldAsText(doc.MaterialsAndMethods.MethodUsed.GLPCompliance)}</#local>
    </#if>

    <#return glp/>
</#function>




